@@ -47,6 +47,14 @@ typedef int sasl_getcallback_t(sasl_conn_t *conn,
 			       int (**pproc)(),
 			       void **pcontext);
 
+#ifdef WIN32
+//need to handle the fact that errno has been defined as a function
+//in a dll, not an extern int
+#ifdef errno
+#undef errno
+#endif //errno
+#endif //WIN32
+
 /* utility function set for plug-ins
  */
 typedef struct sasl_utils {
@@ -96,7 +104,8 @@ typedef struct sasl_utils {
     void (*churn)(sasl_rand_t *rpool, const char *data, unsigned len);
 
     /* current CMU hack.  DO NOT USE EXCEPT IN PLAIN */
-    int (*checkpass)(const char *mech, const char *service,
+    int (*checkpass)(sasl_conn_t *conn,
+		     const char *mech, const char *service,
 		     const char *user, const char *pass);
 
     /* callback function */
