@@ -1,5 +1,6 @@
 /* SASL server API implementation
  * Tim Martin
+ * $Id: server.c,v 1.41 1999/07/30 19:00:19 leg Exp $
  */
 /***********************************************************
         Copyright 1998 by Carnegie Mellon University
@@ -75,7 +76,8 @@ extern int gethostname(char *, int);
  * sasl_setpass
  */
 
-static int _sasl_checkpass(const char *mech, const char *service, 
+static int _sasl_checkpass(sasl_conn_t *conn,
+			   const char *mech, const char *service, 
 			   const char *user, const char *pass);
 
 static int
@@ -326,7 +328,12 @@ int sasl_setpass(sasl_conn_t *conn,
 	_sasl_log(conn,
 		  SASL_LOG_WARNING,
 		  m->plug->mech_name,
-		  tmpresult, errno,
+		  tmpresult,
+#ifndef WIN32
+		  errno,
+#else
+		  GetLastError(),
+#endif //WIN32
 		  "Failed to set secret for %s: %z",
 		  user);
       } else {
@@ -559,6 +566,7 @@ int sasl_server_init(const sasl_callback_t *callbacks,
 		     const char *appname)
 {
   int ret;
+  const sasl_callback_t *vf;
 
   _sasl_server_cleanup_hook = &server_done;
   _sasl_server_idle_hook = &server_idle;
@@ -572,10 +580,15 @@ int sasl_server_init(const sasl_callback_t *callbacks,
   mechlist=sasl_ALLOC(sizeof(mech_list_t));
   if (mechlist==NULL) return SASL_NOMEM;
 
+  vf = _sasl_find_verifyfile_callback(callbacks);
+
   /* load config file if applicable */
-  ret=load_config(_sasl_find_verifyfile_callback(callbacks));
+  ret = load_config(vf);
   if ((ret!=SASL_OK) && (ret!=SASL_CONTINUE)) return ret;
 
+  /* check db */
+  ret = _sasl_server_check_db(vf);
+
   /* load plugins */
   ret=init_mechlist();
   if (ret!=SASL_OK)
@@ -607,28 +620,42 @@ _sasl_transition(sasl_conn_t * conn,
 		 const char * pass,
 		 int passlen)
 {
-  if (! conn)
-    return SASL_BADPARAM;
+    const char *dotrans = "n";
+    sasl_getopt_t *getopt;
+    void *context;
 
-  if (! conn->oparams.authid)
-    return SASL_NOTDONE;
+    if (! conn)
+	return SASL_BADPARAM;
 
-  /* check if this is enabled: default to false */
-  if (sasl_config_getswitch("auto_transition", 0) == 0) return SASL_OK;
+    if (! conn->oparams.authid)
+	return SASL_NOTDONE;
 
-  return sasl_setpass(conn,
-		      conn->oparams.authid,
-		      pass,
-		      passlen,
-		      0,
-		      NULL);
+    /* check if this is enabled: default to false */
+    if (_sasl_getcallback(conn, SASL_CB_GETOPT, &getopt, &context) == SASL_OK)
+    {
+	getopt(context, NULL, "auto_transition", &dotrans, NULL);
+	if (dotrans == NULL) dotrans = "n";
+    }
+
+    if (*dotrans == '1' || *dotrans == 'y' ||
+	(*dotrans == 'o' && dotrans[1] == 'n') || *dotrans == 't') {
+	/* ok, it's on! */
+	return sasl_setpass(conn,
+			    conn->oparams.authid,
+			    pass,
+			    passlen,
+			    0,
+			    NULL);
+    }
+
+    return SASL_OK;
 }
 
 
 /* create context for a single SASL connection
  *  service        -- registered name of the service using SASL (e.g. "imap")
  *  serverFQDN     -- Fully qualified server domain name.  NULL means use
- *                    gethostbyname().  Useful for multi-homed servers.
+ *                    gethostname().  Useful for multi-homed servers.
  *  user_realm     -- permits multiple user domains on server, NULL = default
  *  callbacks      -- callbacks (e.g., authorization, lang, new getopt context)
  *  secflags       -- security flags (see above)
@@ -1001,29 +1028,31 @@ int sasl_listmech(sasl_conn_t *conn,
 }
 
 /* returns OK if it's valid */
-static int _sasl_checkpass(const char *mech, const char *service,
+static int _sasl_checkpass(sasl_conn_t *conn,
+			   const char *mech, const char *service,
 			   const char *user, const char *pass)
 {
     int result = SASL_NOMECH;
 
 #ifdef HAVE_PAM
     if (!strcmp(mech, "PAM")) {
-	result = _sasl_PAM_verify_password(user, pass, service, NULL);
+	result = _sasl_PAM_verify_password(conn, user, pass, service, NULL);
     }
 #endif
-
+#ifndef SASL_MINIMAL_SERVER
     if (!strcmp(mech, "passwd")) {
-	result = _sasl_passwd_verify_password(user, pass, NULL);
+	result = _sasl_passwd_verify_password(conn, user, pass, NULL);
     }
-
+#endif //SASL_MINIMAL_SERVER
     if (!strcmp(mech, "shadow")) {
-	result = _sasl_shadow_verify_password(user, pass, NULL);
+	result = _sasl_shadow_verify_password(conn, user, pass, NULL);
     }
 
 #ifdef HAVE_KRB
     if (!strcmp(mech, "kerberos_v4")) {
 	/* check against krb */
-	result = _sasl_kerberos_verify_password(user, pass, service, NULL);
+	result = _sasl_kerberos_verify_password(conn, user, pass, 
+						service, NULL);
     }
 #endif
 
@@ -1068,7 +1097,7 @@ int sasl_checkpass(sasl_conn_t *conn,
 	mech = DEFAULT_PLAIN_MECHANISM;
     }
 
-    result = _sasl_checkpass(mech, conn->service, user, pass);
+    result = _sasl_checkpass(conn, mech, conn->service, user, pass);
     *errstr = NULL;
 
     if (result == SASL_OK) {
