@@ -55,7 +55,8 @@ typedef struct krb_principal {
 #ifndef R_OK
 #define R_OK 04
 #endif
-
+//we also need io.h for access() prototype
+#include <io.h>
 #endif /* WIN32 */
 
 static const char rcsid[] = "$Implementation: Carnegie Mellon SASL " VERSION " $";
@@ -255,7 +256,7 @@ static int privacy_decode(void *context,
 	    *output = text->realloc(*output, *outputlen+extralen);
 	    memcpy(*output + *outputlen, extra, extralen); 
 	    *outputlen += extralen;
-	    free(extra);
+	    text->free(extra);
 	}
     }
     
@@ -430,8 +431,9 @@ server_start(void *glob_context __attribute__((unused)),
 	     void **conn,
 	     const char **errstr)
 {
+#ifndef WIN32
   context_t *text;
-
+#endif //win32
   if (errstr)
     *errstr = NULL;
 
@@ -814,7 +816,7 @@ static int client_continue_step (void *conn_context,
   
   if (text->state==0)
   {
-    VL(("KEBREROS_V4 Step 1\n"));
+    VL(("KERBEROS_V4 Step 1\n"));
 
     *clientout = NULL;
     *clientoutlen = 0;
