@@ -1,6 +1,6 @@
 /* Plain SASL plugin
  * Tim Martin 
- * $Id: plain.c,v 1.31 1999/06/29 19:36:24 leg Exp $
+ * $Id: plain.c,v 1.34 1999/07/23 18:58:59 leg Exp $
  */
 /***********************************************************
         Copyright 1998 by Carnegie Mellon University
@@ -95,6 +95,7 @@ static void free_secret(sasl_utils_t *utils,
 
   (*secret)->len=0;
 
+  /* this fail in the debug version on win32, which does tighter checking */
   utils->free(*secret);
 
   *secret=NULL;
@@ -158,7 +159,8 @@ int verify_password(sasl_server_params_t *params,
 #endif /* HAVE_PAM */
     }
 
-    result = params->utils->checkpass(mech, params->service, user, pass);
+    result = params->utils->checkpass(params->utils->conn,
+				      mech, params->service, user, pass);
     
     return result;
 }
